#!/bin/bash
########################################################################
#
# build_ninja.sh <product_dir> [tar] [source]
#
# NOTE: Ninja itself does not require python to operate, so to avoid a
# dependence upon a particular python we do *not* install any auxiliary
# files that would. Since these are only useful for a mode of use of
# ninja that we do not support (i.e. hand-written ninja code), we do not
# believe this to be a problem.
#
# CHG 2015/03/19.
########################################################################
usage()
{
   echo "USAGE: `basename ${0}` <product_dir> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z "${UPS_DIR}" ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    local setup_ups=${SETUP_UPS}
    unset SETUP_UPS
    source `${UPS_DIR}/bin/ups setup ${setup_ups}`

    setup ssibuildshims "${ssibuildshims_version}" -z "${product_dir}"
    if [ -z "${SSIBUILDSHIMS_DIR}" ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir="${1}"
maketar="${2}"

if [ -z "${product_dir}" ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=ninja
origpkgver=v1_10_0
pkgver=${origpkgver}
ssibuildshims_version=v2_00_00
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarfile=${package}-${pkgdotver}.tar.gz

get_this_dir

get_ssibuildshims

. define_basics NO_QUAL

if [ "${maketar}" = "tar" ] && [ -x "${pkgdir}/bin/ninja" ]
then
    ups exist "${package}" "${pkgver}" || "${SSIBUILDSHIMS_DIR}/bin/declare_product" "${product_dir}" "${package}" "${pkgver}" NO_QUAL CURRENT
    "${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball" -d etc "${product_dir}" "${package}" "${pkgver}" NO_QUAL CURRENT
    exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p "${pkgdir}"
if [ ! -d "${pkgdir}" ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi
mkdir -p "${blddir}"
if [ ! -d "${blddir}" ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

cd "${blddir}"
tar xf "${tardir}/${pkgtarfile}" || ssi_die "untar source failed."
cd "${package}-${pkgdotver}" || ssi_die "unable to change to package build directory."

python=python
type -t "${python}" >/dev/null 2>&1 || \
  ssi_die "ninja installation currently needs access to an unversioned python executable"

IFS=. system_python_version=($("${python}" -V 2>&1 | cut -d' ' -f2))
if (( ${system_python_version[0]} < 2 )) || \
   { (( ${system_python_version[0]} == 2 )) && \
     (( ${system_python_version[1]} < 6 )); }; then # Too old.
  . setup_python ${product_dir} || \
    ssi_die "unable to set up latest python in order to build ninja."
  echo "INFO: Using python ${PYTHON_VERSION} for build only."
fi

set -x
./configure.py --bootstrap || \
  ssi_die "unable to build ninja."

etcdir="${product_dir}/${package}/${pkgver}/etc"

install -d "${etcdir}" || ssi_die "unable to ensure existence of ${etcdir}/"
install -m 0644 misc/{{bash,zsh}-completion,ninja-mode.el,ninja.vim} \
  "${etcdir}/" || \
  ssi_die "unable to install miscellaneous files in ${etcdir}"
install -d "${pkgdir}/bin" || \
  ssi_die "unable to ensure existence of ${pkgdir}/bin"
install ninja "${pkgdir}/bin/" || \
  ssi_die "unable to install ninja binary in ${pkgdir/bin}"
set +x

[[ -x "${pkgdir}/bin/ninja" ]] || \
  ssi_die "failed to create ${pkgdir}/bin/ninja\n       Something is very wrong."

"${SSIBUILDSHIMS_DIR}/bin/declare_product" "${product_dir}" "${package}" "${pkgver}" NO_QUAL CURRENT

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup "${package}" "${pkgver}" -z "${product_dir}"
echo "${package} is installed at ${NINJA_DIR}"

# this must be last because it will exit
if [ "${maketar}" = "tar" ] && [ -x "${pkgdir}/bin/ninja" ]
then
    "${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball" -d etc "${product_dir}" "${package}" "${pkgver}" NO_QUAL CURRENT
fi

exit 0
